const electron = require('electron');
// Module to control application life.
const {app} = electron;
// Module to create native browser window.
const {BrowserWindow} = electron;

// Keep a global reference of the window object, if you don't, the window will
// be closed automatically when the JavaScript object is garbage collected.
let win;

function createWindow() {
  // Create the browser window.
  win = new BrowserWindow({title: 'Hypetron', width: 600, height: 400});

  // and load the index.html of the app.
  win.loadURL(`file://${__dirname}/gui/hypetron/index.html`);

  // Open the DevTools.
  // win.webContents.openDevTools();

  // Emitted when the window is closed.
  win.on('closed', () => {
    // Dereference the window object, usually you would store windows
    // in an array if your app supports multi windows, this is the time
    // when you should delete the corresponding element.
    win = null;
  });
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.on('ready', createWindow);

// Quit when all windows are closed.
app.on('window-all-closed', () => {
  // On OS X it is common for applications and their menu bar
  // to stay active until the user quits explicitly with Cmd + Q
  if (process.platform !== 'darwin') {
    app.quit();
  }
});

app.on('activate', () => {
  // On OS X it's common to re-create a window in the app when the
  // dock icon is clicked and there are no other windows open.
  if (win === null) {
    createWindow();
  }
});

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.

// Hypetron test functions
const {ipcMain} = require('electron');

ipcMain.on('asynchronous-open-dialog', (event, arg) => {
  console.log(arg);
  const {dialog} = require('electron');
  let ret =  dialog.showOpenDialog({properties: ['openFile'],  filters: [{name: 'Images', extensions: ['jpg', 'png', 'gif']}]  });
  event.sender.send('asynchronous-open-dialog-reply', ret);
});

ipcMain.on('synchronous-open-browser', (event, arg) => {
  console.log('URL: '+arg);
  const {BrowserWindow} = require('electron');
  let win = new BrowserWindow({title: 'Hype browser', width: 600, height: 1500});
  win.loadURL(arg);
  let webContents = win.webContents;
  event.returnValue = true;
});

ipcMain.on('synchronous-open-frameless', (event, arg) => {
  console.log('frameless');
  const {BrowserWindow} = require('electron');
  let size_w = Math.round(Math.random()*200+100);
  let size_h = size_w * 2;
  let win = new BrowserWindow({title: 'A small step for Hype', width: size_w, height: size_h, transparent: true, frame: false, resizable: false});
  win.loadURL(`file://${__dirname}/gui/frameless/index.html`);
  let webContents = win.webContents;
  event.returnValue = true;
});
